@@ -104,6 +104,10 @@ var NAVTREE =
       [ "Debugging problems", "markdown.html#markdown_debug", null ]
     ] ],
     [ "Lists", "lists.html", null ],
+    [ "Requirements", "requirements.html", [
+      [ "External Requirements", "requirements.html#external_req", null ],
+      [ "Requirement traceability", "requirements.html#traceability", null ]
+    ] ],
     [ "Grouping", "grouping.html", [
       [ "Topics", "grouping.html#topics", null ],
       [ "Member Groups", "grouping.html#memgroup", null ],
@@ -279,6 +283,7 @@ var NAVTREE =
       [ "\\related &lt;name&gt;", "commands.html#cmdrelated", null ],
       [ "\\relatesalso &lt;name&gt;", "commands.html#cmdrelatesalso", null ],
       [ "\\relatedalso &lt;name&gt;", "commands.html#cmdrelatedalso", null ],
+      [ "\\requirement &lt;id&gt; [(title)]", "commands.html#cmdrequirement", null ],
       [ "\\showinitializer", "commands.html#cmdshowinitializer", null ],
       [ "\\static", "commands.html#cmdstatic", null ],
       [ "\\struct &lt;name&gt; [&lt;header-file&gt;] [&lt;header-name&gt;]", "commands.html#cmdstruct", null ],
@@ -341,6 +346,8 @@ var NAVTREE =
       [ "\\link &lt;link-object&gt;", "commands.html#cmdlink", null ],
       [ "\\ref &lt;name&gt; [\"(text)\"]", "commands.html#cmdref", null ],
       [ "\\refitem &lt;name&gt;", "commands.html#cmdrefitem", null ],
+      [ "\\satisfies &lt;req-id&gt; [(short description)]", "commands.html#cmdsatisfies", null ],
+      [ "\\verifies &lt;req-id&gt; [(short description)]", "commands.html#cmdverifies", null ],
       [ "\\secreflist", "commands.html#cmdsecreflist", null ],
       [ "\\endsecreflist", "commands.html#cmdendsecreflist", null ],
       [ "\\subpage &lt;name&gt; [\"(text)\"]", "commands.html#cmdsubpage", null ],
@@ -457,6 +464,10 @@ var NAVTREE =
     ] ],
     [ "Doxygen's Internals", "arch.html", null ],
     [ "Changelog", "changelog.html", [
+      [ "1.16 Series", "changelog.html#log_1_16", [
+        [ "Release 1.16.1", "changelog.html#log_1_16_1", null ],
+        [ "Release 1.16.0", "changelog.html#log_1_16_0", null ]
+      ] ],
       [ "1.15 Series", "changelog.html#log_1_15", [
         [ "Release 1.15.0", "changelog.html#log_1_15_0", null ]
       ] ],
@@ -529,7 +540,7 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 "additional.html",
-"commands.html#cmdretval"
+"commands.html#cmdrequirement"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronization';
