@@ -1,6 +1,6 @@
 var searchData=
 [
-  ['name_0',['name',['../commands.html#cmdemoji',1,'\emoji "name"'],['../commands.html#cmdproperty',1,'\property (qualified property name)'],['../faq.html#faq_name',1,'How did Doxygen get its name?']]],
+  ['name_0',['name',['../commands.html#cmdemoji',1,'\\emoji &quot;name&quot;'],['../commands.html#cmdproperty',1,'\\property (qualified property name)'],['../faq.html#faq_name',1,'How did Doxygen get its name?']]],
   ['namespace_20are_20not_20documented_1',['Help, some/all of the members of my class / file / namespace are not documented?',['../faq.html#fac_al',1,'']]],
   ['navigation_2',['Navigation',['../customize.html#minor_tweaks_treeview',1,'']]],
   ['nesting_20custom_20command_3',['Nesting custom command',['../custcmd.html#custcmd_nesting',1,'']]],
@@ -11,5 +11,5 @@ var searchData=
   ['not_20parsed_20properly_20anymore_8',['My file with a custom extension is not parsed (properly) (anymore).',['../faq.html#faq_ext_mapping',1,'']]],
   ['not_20shown_20in_20the_20dot_20graphs_9',['Why are dependencies via STL classes not shown in the dot graphs?',['../faq.html#faq_stl',1,'']]],
   ['now_20what_10',['When running make in the latex directory I get &quot;TeX capacity exceeded&quot;. Now what?',['../faq.html#faq_latex',1,'']]],
-  ['number_11',['\version { version number }',['../commands.html#cmdversion',1,'']]]
+  ['number_11',['\\version { version number }',['../commands.html#cmdversion',1,'']]]
 ];
